#
# spec file for package jmol
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jmol
Version:        16.1.13
Release:        1.1
Summary:        3D Viewer for chemical structures
License:        LGPL-2.1-only
Group:          Productivity/Scientific/Chemistry
URL:            http://jmol.sf.net/

#XSource:         https://downloads.sf.net/jmol/Jmol-%version-binary.tar.gz
Source:         jmol-%version.tar.xz
Source2:        https://wiki.jmol.org/images/1/1c/Jmol_icon13.png
Source3:        %name.man
Source4:        %name.desktop
Source9:        sanitize_binpkg.sh
Patch1:         datadir.diff
BuildArch:      noarch
BuildRequires:  desktop-file-utils
BuildRequires:  dos2unix
BuildRequires:  update-desktop-files
BuildRequires:  xz
Requires:       java >= 7

%description
Jmol is a Java-based viewer for chemical structures in 3D with
features for chemicals, crystals, materials and biomolecules.

%prep
%autosetup -p1
cp %{S:2} .

%build
dos2unix CHANGES.txt COPYRIGHT.txt LICENSE.txt README.txt
perl -i -pe 's{\@pkgdatadir\@}{%_datadir/%name}gs' jmol.sh
# man
cp %{S:3} .
sed -i 's/INST_VERSION/%version/' jmol.man
sed -i 's/INST_SUMMARY/%summary/' jmol.man
gzip -9 jmol.man

%install
b="%buildroot"
# jar
mkdir -p "$b/%_datadir/%name"
install -p -m 644 Jmol.jar "$b/%_datadir/%name/"
# script
install -Dpm0755 jmol.sh "$b/%_bindir/jmol"
# icon
install -Dpm0644 Jmol_icon13.png "$b/%_datadir/pixmaps/%name.png"
# manual
install -Dpm0644 jmol.man.gz "$b/%_mandir/man1/jmol.1.gz"
# .desktop
desktop-file-install --dir %buildroot%_datadir/applications %{S:4}
%suse_update_desktop_file %name

%files
%license LICENSE.txt COPYRIGHT.txt
%doc README.txt CHANGES.txt
%_bindir/%name
%_datadir/%name
%_datadir/applications/%name.desktop
%_datadir/pixmaps/%name.png
%_mandir/man1/%name.1.gz

%changelog
* Sun Jun 25 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 16.1.13
  * added a JME 2-D editor tool
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 14.32.73
  * XSF surface files with over about 267 atoms were not
    recognizing presence of surface data
* Mon May 16 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 14.32.55
  * feature change: axes POSITION [x y] "xyz" with symmetry
  * new feature: axes POSITION [x y] "xyzabc"
  * new feature: global user variable dragDropFileType
  * bugfix: deleting atoms from PDB failed
  * bugfix: ModelKit dragAtom did not update measurements
* Mon Feb  8 2021 Jan Engelhardt <jengelh@inai.de>
- update build recipes/scripts to use https [boo#1181924]
- Redownload Source2 because it was some HTML content rather than
  a PNG file
* Thu Dec 24 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 14.31.20
  * Topology CIF reading of _topol_xxx records
  * GenNBOReader supports older NBO 3.0 output.properties
    rather than missing .46 labels file
  * NBO command expanded to allow named orbitals
* Thu Dec 19 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 14.30.1
  * new feature: (undocumented) set picking dragMolecule
  * new feature: set picking dragModel
* Sat Oct 20 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 14.29.26
  * Fixed: Magnetic CIF reader did not handle symmetry operations
    with n/16.
  * Fixed: 3-membered aziridine with non-H substituent should
    be chiral.
* Fri Jan 19 2018 jengelh@inai.de
- Drop bundled jsmol and jspecview from package.
* Mon Dec 25 2017 jengelh@inai.de
- Update to new upstream release 14.27.2
  * new feature: frame MO - goes to first frame with a molecular orbital
  * new feature: functions write("zip") and write("jmol")
- Remove fsf-address.patch
* Sat Jul 16 2016 thod_@gmx.de
- update to version 14.6.1
  some bug fixes
* Sat May 28 2016 thod_@gmx.de
- Add manual
- Split desktop file
- update to version 14.6.0
  selected new feature:
  * CONNECT {pair1} {pair2} ATROPISOMER
  * C13 NMR prediction from http://www.nmrdb.org/service/jsmol13c?smiles=CCCC
  * Jmol SMILES bond atropisomerism ^nm- and ^^nm-
  * SMILES/nonaromatic same as SMILES/noaromatic
  * adds SHOW SMILES/bio  and {*}.find("SMILES/bio") options:
  * print {*}.find("SMILES/hydrogen/") adds hydrogen atoms
  * Jmol now implements a way of indicating atropisomer chirality.
  * full implementation of OpenSMILES and OpenSMARTS in Jmol
  * Polyhedra command allows for min and max radius
  * draw POINTGROUP SPACEGROUP
  * draw SPACEGROUP
  * print pointgroup("spacegroup", @1)
  * show spacegroup/xxxxx
  * show symop 3 @3 "atom"
  * show/draw symop @1 @2
  * show/draw symop @1 @2 n
  * symop() options
  * symop(3,@3,"atom")
  * getProperty("shapeInfo.echo")
  * preliminary MMTF reader
  * set window width height
  * set window "xxx.png"
  * setting DSSR on the fly
  * show chemical xxx  where xxx is a file type
  and many bug fixes
* Sun Mar 13 2016 jengelh@inai.de
- Update to new upstream release 14.5.0
  * bug fix: restoring bonds to a model having fewer bonds than the
  model for which they were saved throws an exception
  * bug fix for "WRITE xxx.ZIP" command crashing Jmol
* Fri Mar 27 2015 jengelh@inai.de
- Update to new upstream release 14.3.13
  * No overview was provided
* Mon Feb  2 2015 jengelh@inai.de
- Update to new upstream release 14.3.12
  * No overview was provided
* Thu Jul 17 2014 jengelh@inai.de
- update to version 14.2.2
  * New features:
  * readers with unit cells may load as trajectories
  * protein sidechain minimization
  * Bug fixes:
  * CASTEP reader broken for multiple cells and geometry optimization
  * set pdbAddHydrogens fails for structures with ANISOU records
  * select x < 0.3 reports error when checking, though it does run
  when executed
  * SMILES for model with nonbonded atoms fails
  * WebPanel error trapping problem; too long file name for tar file
* Wed Jun 11 2014 jengelh@inai.de
- Update to new upstream release 14.0.17
  * New feature functions:
  * "like" operator, strings only
  * (actually 13.1 but undocumented) animation frame [ 51 50 49 48 47 46 45 (etc) 27 1 2 3 4 5 6 7 (etc)....]
  * (application only) -a --autoAnimationDelay
  * {atomset}.modulation(type, t)
  * {xxx}.distance.all({yyy})  returns float[][] of values
  * {xxx}.getProperty("yyy")
  * added simpler associative array notation: [key:value,...]
  * altloc set for msCIF _atom_site_subsystem_code
  * anim frame [a,b,c,d] works with negative numbers to indicate ranges:
  * array.join()
  * array.keys.all
  * array.pop(), array.push()
  * associative array alternative ".." syntax
  * associative array standard "dot" notation
  * asynchronous resumable processes
  * atomSet1.distance.max(atomSet2, TRUE)
  * atomSet1.distance.max(point, TRUE)
  * atomSet1.distance.min(atomSet2, TRUE)
  * atomSet1.distance.min(point, TRUE)
  * Bilbao Crystallographic Server file reader
  * BilbaoReader NONORM option -- reads displacements as actual values, not normalized
  * binary associative arrays
  * byteArray type
  * calculate hbonds structure
  * calculate structure dssr
  * caption "xxxxx" x.x  -- number of seconds to run
  * catchable THROW
  * color(color1, color2, n, asHSL)
  * compare {model1} {model2} SMILES
  * construction/manipulation/saving of ZIP files
  * delete $SAVED savedName
  * dipole ID m1 ALL {...}
  * DSSR output reading
  * escape pressed cancels pending measurement
  * expanded unit cell ijk notation
  * filter "ATOM" opposite of filter "HETATM"
  * filter "MODCELL=x"
  * Gaussian fchk file reader
  * getProperty variableInfo  <expression>
  * getProperty("JSON", ....)
  * getProperty(x, SQL_query)
  * JANA2006 reader adds M40 molecular group support
  * JavaScript: JSmol api Jmol.evaluateVar(applet, expression)
  * JSmol Info.z, Info.zIndexBase
  * JSmol: allow for a user callback for customization of menu
  * JSpecView and Jmol read ACD/Labs assigned spectra block JDX files.
  * JSpecView getSolutionColor fill/all/none/false
  * JSpecView PEAK command -- adds PEAK GC/MS "#1"
  * JSpecView readers for ACD/Labs annotated MS, IR, Raman, and UV/VIS
  * LIKE operator extended to atom expressions
  * load ":inchikey:xxxxx"
  * load "cell=parent" or "cell=standard"
  * load "filename" packed x.x
  * load ... filter "symop=..."
  * load =1msy/dssr
  * load ASYNC ....
  * load files "xxx" + "yyy"
  * load ORIENTATION or load DATA "...orientation..." ...
  * load xxxx filter "CELL=va,vb,vc;oa,ob,oc"
  * mCIF (magnetic CIF) file reader
  * menu item color--atoms--by scheme--vectors
  * modulation 0.2  // sets t-value
  * modulation adjustable by q and t, up to d=3
  * modulation scale x.x
  * Mol3D reader
  * moveTo AXIS [a,b,c,x,y,z]
  * MSCIF reader now allowing up to d=10; was d=6
  * pickedList -- ordered array of recently picked atoms
  * pt1.mul3(pt2)
  * replace()
  * replace(x, y, TRUE)
  * reset PRINT
  * restore UNITCELL
  * RESUME with arguments is synonymous with RESTORE
  * rich SQL logic in GETPROPERTY, getProperty(), and within(dssr,"xxxx.yyy..."):
  * save CONTEXT contextName
  * script ASYNC ....
  * select leadAtom(s)
  * select ON ; select OFF
  * select ON/OFF atom-set
  * select within(dssr,"subset")
  * select x = [array or array variable]
  * select xyz > 1.0
  * set backboneSteps TRUE
  * set bondingVersion
  * set cartoonRibose
  * set echo depth x.x for standard echos
  * set showUnitCellDetails TRUE (default)
  * set showUnitCellInfo TRUE (default)
  * set starWidth
  * set vectorsCentered
  * show CHEMICAL STDINCHI
  * show CHEMICAL STDINCHIKEY
  * show SAVED
  * show symop @1 @2 "fmatrix"
  * show symop n "fmatrix"
  * show(xxx) function
  * THROW command
  * Tinker file reader (and FoldingXYZ reader upgrade)
  * unit cell display includes k (mCIF) and q (CIF, Jana2006) vectors
  * unitcell "abc_offset"
  * unitcell "type"
  * unitcell [ {origin} {a} {b} {c} ]
  * unitcell {555 575 0}
  * unitcell {atomset}
  * unitcell BOUNDBOX
  * unitcell OFFSET and RANGE
  * unitcell RESET (or RESTORE)
  * V3000 reading of DATA SGROUP records:
  * WRITE "filename" AS type
  * write VAR x "filename"
  * x = {*}.find("chemical",type)
  * x = {*}.find("SMILES", "H")
  * x = compare({atomset1}, {atomset2}, "MAP")
  * x = compare({atomset1}, {atomset2}, "MAP", "all")
  * x = compare({atomset1}, {atomset2}, "MAP", "allH")
  * x = compare({atomset1}, {atomset2}, "MAP", "best")
  * x = compare({atomset1}, {atomset2}, "MAP", "bestH")
  * x = compare({atomset1}, {atomset2}, "MAP", "H")
  * x = format("array", data)
  * x = format("base64", data)
  * x = format("byteArray", data)
  * x = format("JSON", data)
  * x = load("myfile",true)
  * x = smilesString.find("chemical",type)
  * x = write("PNGJ")
  * x.pop("key") for an associative array
  * x.push(key,value) for associative array
  * x.bondingRadius added as more appropriate alias for x.ionic
  * x.covalentRadius added as more appropriate alias for x.covalent
  * var x,y,z;
* Mon Apr 28 2014 jengelh@inai.de
- Initial package (version 14.0.13) for build.opensuse.org
